<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../about.ui" line="14"/>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <location filename="../about.ui" line="34"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;LXQt Archiver&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;Arquivador LXQt&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../about.ui" line="57"/>
        <source>A simple and desktop-agnostic Qt file archiver</source>
        <translation>Um arquivador de ficheiros agnóstico, criado em Qt</translation>
    </message>
    <message>
        <location filename="../about.ui" line="67"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://github.com/lxqt/lxqt-archiver&quot;&gt;https://github.com/lxqt/lxqt-archiver&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;
</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://github.com/lxqt/lxqt-archiver&quot;&gt;https://github.com/lxqt/lxqt-archiver&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;
</translation>
    </message>
    <message>
        <location filename="../about.ui" line="91"/>
        <source>Authors</source>
        <translation>Autores/Autoras</translation>
    </message>
    <message>
        <location filename="../about.ui" line="100"/>
        <source>Programming:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;

LXQt Archiver is derived from the following programs:
* Engrampa of MATE desktop
* File Roller of Gnome desktop
</source>
        <translation>Programação:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;

LXQt Archiver teve como base os seguintes programas:
* Engrampa de MATE desktop
* File Roller de Gnome desktop
</translation>
    </message>
    <message>
        <location filename="../about.ui" line="117"/>
        <source>License</source>
        <translation>Licença</translation>
    </message>
    <message>
        <location filename="../about.ui" line="126"/>
        <source>LXQt Archiver

Copyright (C) 2020 the LXQt Team

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.</source>
        <translation>Arquivador LXQt

Direitos de autor (C) 2018-2019 - Equipa LXQt

Este programa é software livre; pode redistribuí-lo e/ou
modificá-lo sob os termos da Licença Pública Geral GNU
tal como publicado pela Free Software Foundation; qualquer das versões 2
da Licença, ou (à sua escolha) qualquer versão posterior.

Este programa é distribuído na esperança de que venha a ser útil,
mas SEM QUALQUER GARANTIA; sem sequer a garantia implícita de
MERCANTABILIDADE ou ADEQUAÇÃO PARA UM FINAL PARTICULAR.  Ver a
GNU General Public License para mais detalhes.

Deverá ter recebido uma cópia da Licença Pública Geral do GNU
juntamente com este programa; se não, escreva para o Software Livre
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.</translation>
    </message>
</context>
<context>
    <name>Archiver</name>
    <message>
        <location filename="../archiver.cpp" line="66"/>
        <source>Archive type not supported.</source>
        <translation>Tipo de arquivo não suportado.</translation>
    </message>
    <message>
        <location filename="../archiver.cpp" line="310"/>
        <source>*%1 files (*%1)</source>
        <translation>Ficheiros *%1 (*%1)</translation>
    </message>
    <message>
        <location filename="../archiver.cpp" line="314"/>
        <source>All supported formats</source>
        <translation>Todos os formatos suportados</translation>
    </message>
</context>
<context>
    <name>ArchiverError</name>
    <message>
        <location filename="../archivererror.cpp" line="25"/>
        <source>Failed to execute the command.</source>
        <translation>Erro ao executar o comando.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="28"/>
        <source>Command is not found.</source>
        <translation>Comando não encontrado.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="31"/>
        <source>The command exited abnormally.</source>
        <translation>O comando terminou abruptamente.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="34"/>
        <source>Password is required.</source>
        <translation>Requer palavra-passe.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="37"/>
        <source>Missing volume.</source>
        <translation>Volume inexistente.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="40"/>
        <source>Bad charset.</source>
        <translation>Codificação inválida.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="43"/>
        <source>Unsupported file format.</source>
        <translation>Formato não suportado.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="46"/>
        <source>Unknown errors happened.</source>
        <translation>Ocorreram erros não conhecidos.</translation>
    </message>
</context>
<context>
    <name>CreateArchiveExtraWidget</name>
    <message>
        <location filename="../create.ui" line="26"/>
        <source> MiB</source>
        <translation> MiB</translation>
    </message>
    <message>
        <location filename="../create.ui" line="36"/>
        <source>Split into volumes of</source>
        <translation>Separar em volumes de</translation>
    </message>
    <message>
        <location filename="../create.ui" line="43"/>
        <source>Password:</source>
        <translation>Palavra-passe:</translation>
    </message>
    <message>
        <location filename="../create.ui" line="50"/>
        <source>Encrypt the file list too</source>
        <translation>Cifrar também a lista de ficheiros</translation>
    </message>
</context>
<context>
    <name>CreateFileDialog</name>
    <message>
        <location filename="../createfiledialog.cpp" line="13"/>
        <source>All files (*)</source>
        <translation>Todos os ficheiros (*)</translation>
    </message>
</context>
<context>
    <name>ExtractArchiveExtraWidget</name>
    <message>
        <location filename="../extract.ui" line="23"/>
        <source>Extract</source>
        <translation>Extrair</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="29"/>
        <source>E&amp;xtract all files</source>
        <translation>E&amp;xtrair todos os ficheiros</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="36"/>
        <source>Ex&amp;tract selected files</source>
        <translation>Ex&amp;trair ficheiros selecionados</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="59"/>
        <source>Actions</source>
        <translation>Ações</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="65"/>
        <source>Re-create folders</source>
        <translation>Recriar pastas</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="72"/>
        <source>Overwrite existing files</source>
        <translation>Substituir ficheiros existentes</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="79"/>
        <source>Do not extract older files</source>
        <translation>Não extrair ficheiros antigos</translation>
    </message>
</context>
<context>
    <name>ExtractFileDialog</name>
    <message>
        <location filename="../extractfiledialog.cpp" line="12"/>
        <source>All files (*)</source>
        <translation>Todos os ficheiros (*)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="314"/>
        <source>File Archiver</source>
        <translation>Arquivador de ficheiros</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>Filter Files...</source>
        <translation>Filtrar ficheiros...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="83"/>
        <source>&amp;File</source>
        <translation>&amp;Ficheiro</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="98"/>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="117"/>
        <source>&amp;View</source>
        <translation>&amp;Ver</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="121"/>
        <source>&amp;Icon Size</source>
        <translation>Tamanho do ícone</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="147"/>
        <source>&amp;Help</source>
        <translation>A&amp;juda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="158"/>
        <source>Main Toolbar</source>
        <translation>Barra de ferramentas principal</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="186"/>
        <source>&amp;About</source>
        <translation>&amp;Acerca</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="195"/>
        <source>&amp;New</source>
        <translation>&amp;Novo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="198"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="207"/>
        <source>&amp;Open</source>
        <translation>&amp;Abrir</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="210"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="218"/>
        <source>Save &amp;As</source>
        <translation>Gu&amp;ardar como</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="227"/>
        <source>&amp;Extract</source>
        <translation>&amp;Extrair</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="232"/>
        <source>&amp;Test</source>
        <translation>&amp;Testar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="240"/>
        <source>&amp;Properties</source>
        <translation>&amp;Propriedades</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="243"/>
        <source>Alt+Return</source>
        <translation>Alt+Return</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="252"/>
        <source>&amp;Close</source>
        <translation>Fe&amp;char</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="255"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="263"/>
        <source>Cu&amp;t</source>
        <translation>Cor&amp;tar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="266"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="274"/>
        <source>&amp;Copy</source>
        <translation>&amp;Copiar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="277"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="285"/>
        <source>&amp;Paste</source>
        <translation>Co&amp;lar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="288"/>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="296"/>
        <source>&amp;Rename</source>
        <translation>&amp;Renomear</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="299"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="304"/>
        <source>&amp;Delete</source>
        <translation>A&amp;pagar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="307"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="312"/>
        <source>&amp;Select All</source>
        <translation>&amp;Selecionar tudo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="315"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="323"/>
        <source>&amp;Find</source>
        <translation>Locali&amp;zar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="326"/>
        <location filename="../mainwindow.ui" line="439"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="335"/>
        <source>&amp;Add Files</source>
        <translation>&amp;Adicionar ficheiros</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="344"/>
        <source>Add F&amp;older</source>
        <translation>Adici&amp;onar pasta</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="349"/>
        <source>Pass&amp;word</source>
        <translation>Pala&amp;vra-passe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="360"/>
        <source>&amp;Toolbar</source>
        <translation>Barra de ferramen&amp;tas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="371"/>
        <source>&amp;Statusbar</source>
        <translation>Barra de e&amp;stado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="382"/>
        <source>&amp;Directory Tree</source>
        <translation>Árvore do &amp;diretório</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="393"/>
        <source>S&amp;how as Folder</source>
        <translation>Mo&amp;strar como pasta</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="401"/>
        <source>Show &amp;All Files</source>
        <translation>Mostr&amp;ar todos os ficheiros</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="410"/>
        <source>St&amp;op</source>
        <translation>&amp;Parar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="413"/>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="418"/>
        <source>&amp;Reload</source>
        <translation>&amp;Recarregar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="421"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="426"/>
        <source>Filename &amp;Encoding</source>
        <translation>Codificação para o nom&amp;e do ficheiro</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="431"/>
        <source>&amp;View Selected Items</source>
        <translation>&amp;Ver itens selecionados</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="436"/>
        <source>&amp;Filter</source>
        <translation>&amp;Filtrar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="447"/>
        <source>&amp;Expand</source>
        <translation>&amp;Expandir</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="450"/>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+Baixo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="458"/>
        <source>&amp;Collapse</source>
        <translation>Re&amp;colher</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="461"/>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+Cima</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="469"/>
        <source>16 px</source>
        <translation>16 px</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="477"/>
        <source>24 px</source>
        <translation>24 px</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="485"/>
        <source>32 px</source>
        <translation>32 px</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="493"/>
        <source>48 px</source>
        <translation>48 px</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="358"/>
        <location filename="../mainwindow.cpp" line="387"/>
        <location filename="../mainwindow.cpp" line="420"/>
        <source>All files (*)</source>
        <translation>Todos os ficheiros (*)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="392"/>
        <location filename="../mainwindow.cpp" line="425"/>
        <source>Add only if &amp;newer</source>
        <translation>Adicio&amp;nar se for mais recente</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="450"/>
        <source>Confirm</source>
        <translation>Confirmação</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="450"/>
        <source>Are you sure you want to delete selected files?</source>
        <translation>Tem a certeza de que deseja apagar os ficheiros selecionados?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="743"/>
        <source>Version: %1</source>
        <translation>Versão: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="830"/>
        <source>%p %</source>
        <translation>%p %</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="934"/>
        <source>Success</source>
        <translation>Sucesso</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="934"/>
        <source>No errors have been found.</source>
        <translation>Não foram encontrados erros.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="912"/>
        <location filename="../mainwindow.cpp" line="969"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="997"/>
        <source>N/A</source>
        <translation>N/D</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1001"/>
        <source>Uncompressed Size:</source>
        <translation>Tamanho sem compressão:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1003"/>
        <source>Compression Ratio:</source>
        <translation>Rácio de compressão:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1058"/>
        <source>File name</source>
        <translation>Nome de ficheiro</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1059"/>
        <source>File Type</source>
        <translation>Tipo de ficheiro</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1060"/>
        <source>File Size</source>
        <translation>Tamanho do ficheiro</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1061"/>
        <source>Modified</source>
        <translation>Modificado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1062"/>
        <source>Encrypted</source>
        <translation>Cifrado</translation>
    </message>
    <message numerus="yes">
        <location filename="../mainwindow.cpp" line="1088"/>
        <source>%n file(s)</source>
        <translation>
            <numerusform>%n ficheiro</numerusform>
            <numerusform>%n ficheiros</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <location filename="../passworddialog.ui" line="14"/>
        <location filename="../passworddialog.cpp" line="60"/>
        <source>Password</source>
        <translation>Palavra-passe</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="20"/>
        <source>Encrypt the file list</source>
        <translation>Cifrar também a lista de ficheiros</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="34"/>
        <source>Show password</source>
        <translation>Mostrar palavra-passe</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="48"/>
        <location filename="../passworddialog.cpp" line="60"/>
        <source>Password:</source>
        <translation>Palavra-passe:</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="61"/>
        <source>&lt;i&gt;&lt;b&gt;Note:&lt;/b&gt; the password will be used to encrypt files you add to the current archive, and to decrypt files you extract from the current archive. When the archive is closed the password will be deleted.&lt;/i&gt;</source>
        <translation>&lt;i&gt;&lt;b&gt;Nota:&lt;/b&gt; a palavra-passe será utilizada para cifrar os ficheiros adicionados ao arquivo atual e para decifrar os ficheiros extraídos do arquivo atual. Quando o arquivo for fechado, a palavra-passe será apagada.&lt;/i&gt;</translation>
    </message>
</context>
<context>
    <name>ProgressDialog</name>
    <message>
        <location filename="../progressdialog.ui" line="14"/>
        <source>Progress</source>
        <translation>Progresso</translation>
    </message>
    <message>
        <location filename="../progressdialog.cpp" line="16"/>
        <source>%p %</source>
        <translation>%p %</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="248"/>
        <location filename="../main.cpp" line="298"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="6"/>
        <source>7-Zip (.7z)</source>
        <translation>7-Zip (.7z)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="7"/>
        <source>Tar compressed with 7z (.tar.7z)</source>
        <translation>Tar comprimido com 7z (.tar.7z)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="8"/>
        <source>Ace (.ace)</source>
        <translation>Ace (.ace)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="9"/>
        <source>Ar (.a)</source>
        <translation>Ar (.a)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="10"/>
        <source>Ar (.ar)</source>
        <translation>Ar (.ar)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="11"/>
        <source>Arj (.arj)</source>
        <translation>Arj (.arj)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="12"/>
        <source>Tar compressed with bzip2 (.tar.bz2)</source>
        <translation>Tar comprimido com bzip2 (.tar.bz2)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="13"/>
        <source>Tar compressed with bzip (.tar.bz)</source>
        <translation>Tar comprimido com bzip (.tar.bz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="14"/>
        <source>Cabinet (.cab)</source>
        <translation>Cabinet (.cab)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="15"/>
        <source>Rar Archived Comic Book (.cbr)</source>
        <translation>Comic Book arquivado com Rar (.cbr)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="16"/>
        <source>Zip Archived Comic Book (.cbz)</source>
        <translation>Comic Book arquivado com Zip (.cbz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="17"/>
        <source>Tar compressed with gzip (.tar.gz)</source>
        <translation>Tar comprimido com gzip (.tar.gz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="18"/>
        <source>Ear (.ear)</source>
        <translation>Ear (.ear)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="19"/>
        <source>Self-extracting zip (.exe)</source>
        <translation>Zip de extração automática (.exe)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="20"/>
        <source>Jar (.jar)</source>
        <translation>Jar (.jar)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="21"/>
        <source>Lha (.lzh)</source>
        <translation>Lha (.lzh)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="22"/>
        <source>Lrzip (.lrz)</source>
        <translation>Lrzip (.lrz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="23"/>
        <source>Tar compressed with lrzip (.tar.lrz)</source>
        <translation>Tar comprimido com lrzip (.tar.lrz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="24"/>
        <source>Tar compressed with lzip (.tar.lz)</source>
        <translation>Tar comprimido com lzip (.tar.lz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="25"/>
        <source>Tar compressed with lzma (.tar.lzma)</source>
        <translation>Tar comprimido com lzma (.tar.lzma)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="26"/>
        <source>Tar compressed with lzop (.tar.lzo)</source>
        <translation>Tar comprimido com lzop (.tar.lzo)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="27"/>
        <source>Windows Imaging Format (.wim)</source>
        <translation>Formato Windows Imaging (.wim)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="28"/>
        <source>Rar (.rar)</source>
        <translation>Rar (.rar)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="29"/>
        <source>Tar uncompressed (.tar)</source>
        <translation>Tar sem compressão (.tar)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="30"/>
        <source>Tar compressed with compress (.tar.Z)</source>
        <translation>Tar comprimido com compress (.tar.Z)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="31"/>
        <source>War (.war)</source>
        <translation>War (.war)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="32"/>
        <source>Xz (.xz)</source>
        <translation>Xz (.xz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="33"/>
        <source>Tar compressed with xz (.tar.xz)</source>
        <translation>Tar comprimido com xz (.tar.xz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="34"/>
        <source>Tar compressed with zstd (.tar.zst)</source>
        <translation>Tar comprimido com zstd (.tar.zst)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="35"/>
        <source>Zoo (.zoo)</source>
        <translation>Zoo (.zoo)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="36"/>
        <source>Zip (.zip)</source>
        <translation>Zip (.zip)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="39"/>
        <location filename="../corestrs.h" line="46"/>
        <location filename="../corestrs.h" line="62"/>
        <location filename="../main.cpp" line="240"/>
        <source>Adding file: </source>
        <translation>A adicionar ficheiro: </translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="40"/>
        <location filename="../corestrs.h" line="49"/>
        <location filename="../corestrs.h" line="64"/>
        <location filename="../main.cpp" line="280"/>
        <source>Extracting file: </source>
        <translation>A extrair ficheiro: </translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="43"/>
        <source>%d %B %Y, %H:%M</source>
        <translation>%d %B %Y, %H:%M</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="47"/>
        <location filename="../corestrs.h" line="63"/>
        <source>Removing file: </source>
        <translation>A remover ficheiro: </translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="48"/>
        <source>Deleting files from archive</source>
        <translation>A apagar ficheiros do arquivo</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="50"/>
        <source>Recompressing archive</source>
        <translation>A comprimir ficheiro</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="51"/>
        <source>Decompressing archive</source>
        <translation>A descomprimir arquivo</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="54"/>
        <source>File not found.</source>
        <translation>Ficheiro não encontrado.</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="55"/>
        <source>Archive type not supported.</source>
        <translation>Arquivo não suportado.</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="56"/>
        <source>Archive not found</source>
        <translation>Arquivo não encontrado</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="57"/>
        <source>You don&apos;t have the right permissions.</source>
        <translation>Não tem as permissões necessárias.</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="58"/>
        <source>This archive type cannot be modified</source>
        <translation>Este tipo de arquivo não pode ser modificado</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="59"/>
        <source>You can&apos;t add an archive to itself.</source>
        <translation>Não pode adicionar um arquivo para si mesmo.</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="65"/>
        <source>Could not find the volume: %s</source>
        <translation>Não foi possível localizar o volume: %s</translation>
    </message>
</context>
</TS>
